@@ -4,19 +4,18 @@
  *
  * Copyright (c) 2010-2011 Peng Wu <alexepico@gmail.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
+ *  This program is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "PYEnglishEditor.h"
@@ -374,7 +373,7 @@ EnglishEditor::EnglishEditor (PinyinProperties & props, Config &config)
         m_english_database->openDatabase
         (PKGDATADIR G_DIR_SEPARATOR_S "db" G_DIR_SEPARATOR_S "english.db", path);
     if (!result)
-        g_warning ("can't open english word list database.\n");
+        g_warning ("can't open English word list database.\n");
 }
 
 EnglishEditor::~EnglishEditor ()
@@ -549,6 +548,11 @@ EnglishEditor::processSpace (guint keyval)
     if (!(keyval == IBUS_space || keyval == IBUS_KP_Space))
         return FALSE;
 
+    if (m_text == "v" || m_text == "V") {
+        reset ();
+        return TRUE;
+    }
+
     guint cursor_pos = m_lookup_table.cursorPos ();
     return selectCandidate (cursor_pos);
 }
@@ -611,7 +615,7 @@ EnglishEditor::updateStateFromInput (void)
     if (1 == m_text.length ()) {
         clearLookupTable ();
 
-        const char * help_string = _("Please input the english word.");
+        const char * help_string = _("Please input the English word.");
         int space_len = std::max ( 0, m_aux_text_len
                                    - (int) g_utf8_strlen (help_string, -1));
         m_auxiliary_text.append (space_len, ' ');
