@@ -4,19 +4,18 @@
  *
  * Copyright (c) 2011 Peng Wu <alexepico@gmail.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
+ *  This program is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "PYPBopomofoEditor.h"
@@ -47,6 +46,10 @@ BopomofoEditor::BopomofoEditor
       m_select_mode (FALSE)
 {
     m_instance = LibPinyinBackEnd::instance ().allocChewingInstance ();
+
+#ifdef ENABLE_CLOUD_INPUT_MODE
+    m_cloud_candidates.setInputMode (Bopomofo);
+#endif
 }
 
 BopomofoEditor::~BopomofoEditor (void)
@@ -342,6 +345,10 @@ BopomofoEditor::commit (const gchar *str)
 void
 BopomofoEditor::updatePreeditText ()
 {
+    if (DISPLAY_STYLE_COMPACT == m_config.displayStyle () ||
+        DISPLAY_STYLE_COMPATIBILITY == m_config.displayStyle ())
+        return;
+
     guint num = 0;
     pinyin_get_n_candidate (m_instance, &num);
 
@@ -391,13 +398,19 @@ BopomofoEditor::updatePreeditText ()
     guint cursor = getPinyinCursor ();
     pinyin_get_character_offset(m_instance, sentence, cursor, &offset);
     Editor::updatePreeditText (preedit_text, offset, TRUE);
+
+    g_free (sentence);
 }
 
 void
 BopomofoEditor::updateAuxiliaryText (void)
 {
     if (G_UNLIKELY (m_text.empty ())) {
-        hideAuxiliaryText ();
+        if (DISPLAY_STYLE_TRADITIONAL == m_config.displayStyle () ||
+            DISPLAY_STYLE_COMPATIBILITY == m_config.displayStyle ())
+            hideAuxiliaryText ();
+        if (DISPLAY_STYLE_COMPACT == m_config.displayStyle ())
+            hidePreeditText ();
         return;
     }
 
@@ -413,6 +426,10 @@ BopomofoEditor::updateAuxiliaryText (void)
     m_buffer << p;
 
     StaticText text (m_buffer);
-    Editor::updateAuxiliaryText (text, TRUE);
+    if (DISPLAY_STYLE_TRADITIONAL == m_config.displayStyle () ||
+        DISPLAY_STYLE_COMPATIBILITY == m_config.displayStyle ())
+        Editor::updateAuxiliaryText (text, TRUE);
+    if (DISPLAY_STYLE_COMPACT == m_config.displayStyle ())
+        Editor::updatePreeditText (text, 0, TRUE);
 }
 
