@@ -4,19 +4,18 @@
  *
  * Copyright (c) 2011 Peng Wu <alexepico@gmail.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
+ *  This program is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "PYPPhoneticEditor.h"
@@ -38,6 +37,9 @@ PhoneticEditor::PhoneticEditor (PinyinProperties &props,
     m_lua_converter_candidates (this),
 #endif
     m_emoji_candidates (this),
+#ifdef ENABLE_CLOUD_INPUT_MODE
+    m_cloud_candidates(this),
+#endif
     m_traditional_candidates (this, config)
 {
 }
@@ -179,10 +181,8 @@ PhoneticEditor::processFunctionKey (guint keyval, guint keycode, guint modifiers
         case IBUS_D:
             {
                 guint index = m_lookup_table.cursorPos ();
-                lookup_candidate_t * candidate = NULL;
-                pinyin_get_candidate (m_instance, index, &candidate);
-                if (pinyin_is_user_candidate (m_instance, candidate)) {
-                    pinyin_remove_user_candidate (m_instance, candidate);
+                if (index < m_candidates.size () &&
+                    removeCandidateInternal (m_candidates[index])) {
                     updatePinyin ();
                     update ();
                 }
@@ -242,6 +242,12 @@ PhoneticEditor::updateCandidates (void)
     }
 #endif
 
+#ifdef ENABLE_CLOUD_INPUT_MODE
+    /* keep me behind the other kinds of candidates which are inserted after n-gram candidates */
+    if(m_config.enableCloudInput ())
+        m_cloud_candidates.processCandidates (m_candidates);
+#endif
+
     if (!m_props.modeSimp ())
         m_traditional_candidates.processCandidates (m_candidates);
 
@@ -370,6 +376,11 @@ PhoneticEditor::selectCandidateInternal (EnhancedCandidate & candidate)
     case CANDIDATE_TRADITIONAL_CHINESE:
         return m_traditional_candidates.selectCandidate (candidate);
 
+#ifdef ENABLE_CLOUD_INPUT_MODE
+    case CANDIDATE_CLOUD_INPUT:
+        return m_cloud_candidates.selectCandidate (candidate);
+#endif
+
 #ifdef IBUS_BUILD_LUA_EXTENSION
     case CANDIDATE_LUA_TRIGGER:
         return m_lua_trigger_candidates.selectCandidate (candidate);
@@ -386,6 +397,34 @@ PhoneticEditor::selectCandidateInternal (EnhancedCandidate & candidate)
     }
 }
 
+gboolean
+PhoneticEditor::removeCandidateInternal (EnhancedCandidate & candidate)
+{
+    switch (candidate.m_candidate_type) {
+    case CANDIDATE_NBEST_MATCH:
+    case CANDIDATE_NORMAL:
+    case CANDIDATE_USER:
+        return m_libpinyin_candidates.removeCandidate (candidate);
+
+    case CANDIDATE_TRADITIONAL_CHINESE:
+        return m_traditional_candidates.removeCandidate (candidate);
+
+#ifdef IBUS_BUILD_LUA_EXTENSION
+    case CANDIDATE_LUA_TRIGGER:
+        return m_lua_trigger_candidates.removeCandidate (candidate);
+
+    case CANDIDATE_LUA_CONVERTER:
+        return m_lua_converter_candidates.removeCandidate (candidate);
+#endif
+
+    case CANDIDATE_EMOJI:
+        return m_emoji_candidates.removeCandidate (candidate);
+
+    default:
+        assert (FALSE);
+    }
+}
+
 #if 0
 gboolean
 PhoneticEditor::selectCandidate (guint i)
